import requests
from http import HTTPStatus

def notify(url, headers, payload):
    response = requests.post(url, headers=headers, json=payload)
    if response.status_code != HTTPStatus.CREATED:
        print(f"Webhook status response: {response.status_code}")
    return response.json()


from http import HTTPStatus
import requests

def slack_notify(url, title, text, color="#B22222"):
    try:
        payload = {"attachments": [{"color": color, "title": title, "text": text}]}
        headers = {"Content-Type": "application/json"}
        response = requests.post(url, headers=headers, json=payload)
        if response.status_code != HTTPStatus.OK:
            raise Exception("Error to notify slack")
        return response
    except Exception as e:
        print(f"slack error: {e}")



import base64
import struct
def validate_ssh(key, accepted_type="ssh-rsa"):
    try:
        prefix, key_string = key.split()
        data = base64.b64decode(key_string.encode('ASCII'))
        int_len = 4
        str_len = struct.unpack('>I', data[:int_len])[0]  # this should return 7
        return (data[int_len:int_len + str_len].decode('ASCII') == accepted_type)
    except Exception as e:
        return False


#!/usr/bin/env python

from sqlalchemy import create_engine
from sqlalchemy import text

def connect(db=None, user=None, host=None, port=None, passwd=None, uri=None, pool_size = 50):
    try:
        print("Connecting to PostgreSQL database!")
        if uri:
            return _get_engine_from_uri(uri, pool_size = pool_size)
        return get_engine(db, user, host, port, passwd, pool_size)
    except IOError:
        print("Failed to get database connection!")
        return None, 'fail'

def get_engine(db, user, host, port, passwd, pool_size):
    uri = 'postgresql://{user}:{passwd}@{host}:{port}/{db}'.format(user=user, passwd=passwd, host=host, port=port, db=db)
    return _get_engine_from_uri(uri, pool_size=pool_size)

def _get_engine_from_uri(uri, pool_size):
    return create_engine(uri, pool_size=pool_size)

def execute(conn, sql_command):
    result = conn.execute(text(sql_command))
    try:
        return [dict(row) for row in result]
    except Exception:
        return result


#!/usr/bin/env python

import requests
from requests.auth import HTTPBasicAuth
from http import HTTPStatus

class Zendesk(object):
    def __init__(self, user, password):
        self.auth = HTTPBasicAuth(user, password)

    def create_ticket(self, url, subject, description, custom_fields, ticket_form_id=360000793711):
        headers = {'Content-Type': 'application/json'}
        payload = {
            "ticket": {
                "ticket_form_id": ticket_form_id,
                "type": "task",
                "subject": subject,
                "comment": {
                    "body": description
                },
                "custom_fields": custom_fields
            }
        }
        response = requests.post(
            url, auth=self.auth, headers=headers, json=payload)
        if response.status_code != HTTPStatus.CREATED:
            raise Exception(f"Zendesk status response: {response.status_code}")
        return response.json()

    def get_ticket(self, url, ticket_id):
        headers = {'Content-Type': 'application/json'}
        response = requests.get(url.format(ticket_id),
                                auth=self.auth, headers=headers)
        if response.status_code != HTTPStatus.OK:
            raise Exception(f"Zendesk status response: {response.status_code}")
        return response.json()



import re

CASES = [' ', ";", ","]

def is_valid_email(email, regex):
    if email is None:
        return False
    if not isinstance(email, str):
        return False
    if email.strip() == "":
        return False
    for case in CASES:
        if case in email:
            return False
    return re.search(regex, email.lower())




import os
import boto3

from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.application import MIMEApplication

def send_email(sender_name, sender_email, recipient_email, subject, body_text, body_html=None, attachment=None, region_name='us-east-1'):
    try:
        client = boto3.client('ses', region_name=region_name)
        charset = "utf-8"

        msg = MIMEMultipart('mixed')

        msg['Subject'] = subject
        msg['From'] = f'{sender_name} <{sender_email}>'
        msg['To'] = recipient_email

        msg_body = MIMEMultipart('alternative')

        textpart = MIMEText(body_text, 'plain', charset)

        msg_body.attach(textpart)

        if body_html:
            htmlpart = MIMEText(body_html, 'html', charset)
            msg_body.attach(htmlpart)

        if attachment:
            att = MIMEApplication(open(attachment, 'rb').read())
            att.add_header('Content-Disposition', 'attachment', filename=os.path.basename(attachment))
            msg.attach(att)

        msg.attach(msg_body)

        response = client.send_raw_email(
            Source=msg['From'],
            Destinations=[msg['To']],
            RawMessage={'Data': msg.as_string()}
        )

        return response
    except Exception as e:
        print(e)
        raise e



import boto3

DEFAULT_LOCATION = 'us-east-1'

def create_bucket_with_options(bucket_name,
                               tag_set,
                               server_side_encryption_rules,
                               acl='private',
                               region='us-east-1',
                               enable_versioning=False,
                               location_constraint=DEFAULT_LOCATION):

    print("create_bucket_with_options")
    print(f"bucket_name: {bucket_name}")
    print(f"region: {region}")
    print(f"enable_versioning: {enable_versioning}")
    print(f"location_constraint: {location_constraint}")

    s3_resource = boto3.resource('s3', region_name=region)

    response_bucket_create = None

    if location_constraint == DEFAULT_LOCATION:
        response_bucket_create = s3_resource.create_bucket(
            ACL=acl,
            Bucket=bucket_name
        )
    else:
        response_bucket_create = s3_resource.create_bucket(
            ACL=acl,
            Bucket=bucket_name,
            CreateBucketConfiguration={
                'LocationConstraint': location_constraint}
        )


    if enable_versioning:
        bkt_versioning = s3_resource.BucketVersioning(bucket_name)
        bkt_versioning.enable()

    s3_client = boto3.client('s3', region_name=region)

    response_bucket_tagging = s3_client.put_bucket_tagging(
        Bucket=bucket_name,
        Tagging={
            'TagSet': tag_set,
        },
    )

    response_bucket_encryption = s3_client.put_bucket_encryption(
        Bucket=bucket_name,
        ServerSideEncryptionConfiguration={
            'Rules': server_side_encryption_rules
        }
    )

    return response_bucket_create, response_bucket_tagging, response_bucket_encryption



import boto3
import ast
import jwt

from botocore.exceptions import ClientError

DEFAULTS = {
        'verify_signature': False,
        'verify_aud': False,
        'verify_iat': False,
        'verify_exp': False,
        'verify_nbf': False,
        'verify_iss': False,
        'verify_sub': False,
        'verify_jti': False,
        'verify_at_hash': False,
        'leeway': 0}

def get_app_client(authorization):
    return jwt.decode(authorization, algorithms=['RS256'], options=DEFAULTS)['client_id']

def get_secrets(region, secret):
    try:
        session = boto3.session.Session()
        client = session.client(service_name='secretsmanager', region_name=region)
        response = client.get_secret_value(SecretId=secret)
        return ast.literal_eval(response['SecretString'])
    except ClientError as e:
        raise e

def get_issuer(region, authorization):
    return get_secrets(region=region, secret=get_app_client(authorization))


import boto3
import json

def enqueue(queue_name, payload):
    sqs = boto3.client('sqs')
    response = sqs.send_message(
        QueueUrl=queue_name,
        MessageAttributes=payload["attributes"],
        MessageBody=json.dumps(payload["body"])
    )
    return response

def delete_message(queue_url, record):
    sqs = boto3.client('sqs')
    return sqs.delete_message(QueueUrl=queue_url, ReceiptHandle=record['receiptHandle'])

def is_there_notification(context):
    return 'Records' in context and len(context) >= 1